enumAssociativity
enum Associativity: string
Public API: explicitly declared with
@visibility public.The four precedence directives: %left, %right, %nonassoc and %precedence.
%binary is the deprecated spelling of %nonassoc and reads as it.
\BisonParser\Ast\Declaration\Symbols\Associativity::from('nonassoc')->name // => 'NonAssoc'Cases
case Left = 'left'case Right = 'right'case NonAssoc = 'nonassoc'case Precedence = 'precedence'Test cases 7
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 6
Relations
Static calls 1
Constant reads 4
- class-const SqlParser\Compiler\BisonGrammarReader::associativity() packages/sql-parser/src/Compiler/BisonGrammarReader.php:124
- class-const SqlParser\Compiler\BisonGrammarReader::associativity() packages/sql-parser/src/Compiler/BisonGrammarReader.php:125
- class-const SqlParser\Compiler\BisonGrammarReader::associativity() packages/sql-parser/src/Compiler/BisonGrammarReader.php:126
- class-const SqlParser\Compiler\BisonGrammarReader::associativity() packages/sql-parser/src/Compiler/BisonGrammarReader.php:127