enumSymbolClass
enum SymbolClass: string
Public API: explicitly declared with
@visibility public.Which directive declared a list of symbols: %token, %nterm or %type.
%term is the deprecated spelling of %token and reads as it.
\BisonParser\Ast\Declaration\Symbols\SymbolClass::from('nterm')->name // => 'Nonterminal'Cases
case Token = 'token'case Nonterminal = 'nterm'case Type = 'type'Test cases 8
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 7
Relations
Constant reads 5
- class-const BisonParser\Syntax\DeclarationParser::directive() packages/bison-parser/src/Syntax/DeclarationParser.php:130
- class-const BisonParser\Syntax\DeclarationParser::directive() packages/bison-parser/src/Syntax/DeclarationParser.php:131
- class-const BisonParser\Syntax\DeclarationParser::directive() packages/bison-parser/src/Syntax/DeclarationParser.php:132
- class-const SqlFaker\Compiler\Bison\BisonGrammarCompiler::declaredTokens() packages/sql-faker/src/Compiler/Bison/BisonGrammarCompiler.php:93
- class-const SqlParser\Compiler\BisonGrammarReader::declaration() packages/sql-parser/src/Compiler/BisonGrammarReader.php:103